@@ -8,3 +8,7 @@ class Native:
     @staticmethod
     def insert(table_name, colunms, values):
         return f'INSERT INTO {table_name}{colunms} VALUES{values}'
+
+    @staticmethod
+    def update(table_name, sets, where):
+        return f'UPDATE {table_name} SET {sets} WHERE 1=1 AND {where}'
