@@ -18,10 +18,10 @@ class ORMSync:
         self.__attrs_to_id = attrs_to_id or None
         self.__id = ''
 
-    def to_json(self, obj, attrs_to_ignore=None, attrs_to_id=None):
+    def to_json(self, obj, attrs_to_ignore=None, attrs_to_id=None, accept_list=False):
         self.__prepare(attrs_to_ignore, attrs_to_id)
         self.__set_keys(obj)
-        self.__generate_json(obj)
+        self.__generate_json(obj, accept_list)
 
         return self.__id, self.__json
 
@@ -35,12 +35,15 @@ class ORMSync:
 
         return True if callable(getattr(obj, key)) or self.__attrs_to_ignore.__contains__(key) else False
 
-    def __generate_json(self, obj):
+    def __generate_json(self, obj, accept_list):
         self.__clear_json()
 
         for key in self.__keys:
             if isinstance(obj.__getattribute__(key), list):
-                continue
+                if not accept_list:
+                    continue
+
+                self.__json.update({key: self.__convert_list(obj.__getattribute__(key))})
 
             elif isinstance(obj.__getattribute__(key), datetime):
                 self.__json.update({key: str(obj.__getattribute__(key))})
@@ -69,3 +72,12 @@ class ORMSync:
     def __clear_json(self):
         if self.__json:
             self.__json = {}
+
+    @staticmethod
+    def __convert_list(data):
+        converted = []
+
+        for info in data:
+            converted.append(str(info))
+
+        return converted
